Struct GenericArrayIter

struct GenericArrayIter<T, N: ArrayLength<T>> { ... }

An iterator that moves out of a GenericArray

Implementations

impl<T, N> GenericArrayIter<T, N>

fn as_slice(self: &Self) -> &[T]

Returns the remaining items of this iterator as a slice

fn as_mut_slice(self: &mut Self) -> &mut [T]

Returns the remaining items of this iterator as a mutable slice

impl<I> IntoIterator for GenericArrayIter<T, N>

fn into_iter(self: Self) -> I

impl<T> Any for GenericArrayIter<T, N>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GenericArrayIter<T, N>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GenericArrayIter<T, N>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for GenericArrayIter<T, N>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for GenericArrayIter<T, N>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Same for GenericArrayIter<T, N>

impl<T, N> DoubleEndedIterator for GenericArrayIter<T, N>

fn next_back(self: &mut Self) -> Option<T>
fn rfold<B, F>(self: Self, init: B, f: F) -> B
where
    F: FnMut(B, <Self as >::Item) -> B

impl<T, N> Drop for GenericArrayIter<T, N>

fn drop(self: &mut Self)

impl<T, N> ExactSizeIterator for GenericArrayIter<T, N>

fn len(self: &Self) -> usize

impl<T, N> Freeze for GenericArrayIter<T, N>

impl<T, N> FusedIterator for GenericArrayIter<T, N>

impl<T, N> Iterator for GenericArrayIter<T, N>

fn next(self: &mut Self) -> Option<T>
fn fold<B, F>(self: Self, init: B, f: F) -> B
where
    F: FnMut(B, <Self as >::Item) -> B
fn size_hint(self: &Self) -> (usize, Option<usize>)
fn count(self: Self) -> usize
fn nth(self: &mut Self, n: usize) -> Option<T>
fn last(self: Self) -> Option<T>

impl<T, N> RefUnwindSafe for GenericArrayIter<T, N>

impl<T, N> Send for GenericArrayIter<T, N>

impl<T, N> Sync for GenericArrayIter<T, N>

impl<T, N> Unpin for GenericArrayIter<T, N>

impl<T, N> UnsafeUnpin for GenericArrayIter<T, N>

impl<T, N> UnwindSafe for GenericArrayIter<T, N>

impl<T, U> Into for GenericArrayIter<T, N>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GenericArrayIter<T, N>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GenericArrayIter<T, N>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: Clone, N> Clone for GenericArrayIter<T, N>

fn clone(self: &Self) -> Self

impl<T: fmt::Debug, N> Debug for GenericArrayIter<T, N>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result