Trait FunctionalSequence
unsafe trait FunctionalSequence<T>: GenericSequence<T>
Defines functional programming methods for generic sequences
Provided Methods
fn map<U, F>(self: Self, f: F) -> MappedSequence<Self, T, U> where Self: MappedGenericSequence<T, U>, <Self as >::Length: ArrayLength<U>, F: FnMut(<Self as >::Item) -> UMaps a
GenericSequenceto anotherGenericSequence.If the mapping function panics, any already initialized elements in the new sequence will be dropped, AND any unused elements in the source sequence will also be dropped.
fn zip<B, Rhs, U, F>(self: Self, rhs: Rhs, f: F) -> MappedSequence<Self, T, U> where Self: MappedGenericSequence<T, U>, Rhs: MappedGenericSequence<B, U, Mapped = MappedSequence<Self, T, U>> + GenericSequence<B, Length = <Self as >::Length>, <Self as >::Length: ArrayLength<B> + ArrayLength<U>, F: FnMut(<Self as >::Item, <Rhs as >::Item) -> UCombines two
GenericSequenceinstances and iterates through both of them, initializing a newGenericSequencewith the result of the zipped mapping function.If the mapping function panics, any already initialized elements in the new sequence will be dropped, AND any unused elements in the source sequences will also be dropped.
fn fold<U, F>(self: Self, init: U, f: F) -> U where F: FnMut(U, <Self as >::Item) -> UFolds (or reduces) a sequence of data into a single value.
If the fold function panics, any unused elements will be dropped.
Implementors
impl<'a, T, S: GenericSequence<T>> FunctionalSequence for &'a Simpl<T, N> FunctionalSequence for GenericArray<T, N>impl<'a, T, S: GenericSequence<T>> FunctionalSequence for &'a mut S