Trait Split
unsafe trait Split<T, K>: GenericSequence<T>
where
K: ArrayLength<T>
Defines a GenericSequence that can be split into two parts at a given pivot index.
Associated Types
type First: TraitBound { trait_: Path { path: "GenericSequence", id: Id(13), args: Some(AngleBracketed { args: [Type(Generic("T"))], constraints: [] }) }, generic_params: [], modifier: None }First part of the resulting split array
type Second: TraitBound { trait_: Path { path: "GenericSequence", id: Id(13), args: Some(AngleBracketed { args: [Type(Generic("T"))], constraints: [] }) }, generic_params: [], modifier: None }Second part of the resulting split array
Required Methods
fn split(self: Self) -> (<Self as >::First, <Self as >::Second)Splits an array at the given index, returning the separate parts of the array.
Implementors
impl<'a, T, N, K> Split for &'a mut GenericArray<T, N>impl<T, N, K> Split for GenericArray<T, N>impl<'a, T, N, K> Split for &'a GenericArray<T, N>