Type Alias SequenceItem

type SequenceItem = <T as IntoIterator>::Item

Accessor for GenericSequence item type, which is really IntoIterator::Item

For deeply nested generic mapped sequence types, like shown in tests/generics.rs, this can be useful for keeping things organized.