Trait ArrayLength

unsafe trait ArrayLength<T>: Unsigned

Trait making GenericArray work, marking types to be used as length of an array

Associated Types

type ArrayType

Associated type representing the array type for the number

Implementors