Trait ArrayLength
unsafe trait ArrayLength<T>: Unsigned
Trait making GenericArray work, marking types to be used as length of an array
Associated Types
type ArrayTypeAssociated type representing the array type for the number
Implementors
impl<T, N: ArrayLength<T>> ArrayLength for UInt<N, B0>impl<T> ArrayLength for UTermimpl<T, N: ArrayLength<T>> ArrayLength for UInt<N, B1>